@@ -30,6 +30,7 @@
 #include <KHelpClient>
 #include <KMessageBox>
 
+#include <KJobTrackerInterface>
 #include <QComboBox>
 #include <QFont>
 #include <QHBoxLayout>
@@ -38,7 +39,6 @@
 #include <QTemporaryFile>
 #include <kio/global.h>
 #include <kio/renamedialog.h>
-#include <kjobtrackerinterface.h>
 
 KGpgExternalActions::KGpgExternalActions(KeysManager *parent, KGpgItemModel *model)
 	: QObject(parent),
@@ -123,7 +123,7 @@ void KGpgExternalActions::encryptFolders(KeysManager *parent, const QList<QUrl>
 
 	if (!tmpfolder->open()) {
 		delete tmpfolder;
-		KMessageBox::sorry(parent, i18n("Cannot create temporary file for folder compression."), i18n("Temporary File Creation"));
+		KMessageBox::error(parent, i18n("Cannot create temporary file for folder compression."), i18n("Temporary File Creation"));
 		return;
 	}
 
@@ -225,7 +225,7 @@ void KGpgExternalActions::slotFolderFinished(KJob *job)
 	Q_ASSERT(trayinfo != nullptr);
 
 	if (trayinfo->error())
-		KMessageBox::sorry(m_keysmanager, trayinfo->errorString());
+		KMessageBox::error(m_keysmanager, trayinfo->errorString());
 
 	deleteLater();
 }
